@@ -1,23 +1,23 @@
 # lcreg: Efficent rigid and affine 3D image registration
-# 
+#
 # Copyright (C) 2019  Peter Rösch, Peter.Roesch@hs-augsburg.de
-# 
+#
 # Organisation:
 # Faculty of Computer Science, Augsburg University of Applied Sciences,
 # An der Hochschule 1, 86161 Augsburg, Germany
-# 
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-name = 'lcreg'
-__version__ = '0.1.3'
+name = "lcreg"
+__version__ = "0.1.4"
